@@ -1,6 +1,7 @@
+import http
 import json
-
-
+import http.client
+import ssl
 import time
 import requests
 from requests.adapters import HTTPAdapter
@@ -34,7 +35,7 @@ accept_header = "application/vnd.github.mercy-preview+json"
 errors = []
 
 s = requests.Session()
-retries = Retry(total=5, backoff_factor=1, status_forcelist=[404, 422])
+retries = Retry(total=5, backoff_factor=2, status_forcelist=[404, 422])
 s.mount('https://', HTTPAdapter(max_retries=retries))
 
 
@@ -189,12 +190,13 @@ def rename_repo(repo, org, answers, headers):
     try:
         time.sleep(1)
         team_prefix = answers.get("prefix")
-        logging.info(f"Renaming {repo} to {team_prefix}.{repo}")
+        logging.info(f"Renaming {repo} to {team_prefix}.{repo} in {org}")
         url = f"https://api.github.com/repos/{org}/{repo}"
 
         data = {"name": team_prefix + "." + repo}
-        rename_response = s.patch(url=url, headers=headers,
-                                  data=json.dumps(data))
+        headers["Accept"] = "application/vnd.github.v3+json"
+        logging.info(url)
+        rename_response = s.request("PATCH", url=url, data=json.dumps(data), headers=headers)
 
         if rename_response.status_code == 200:
             logging.info("Renamed successfully")
@@ -416,8 +418,9 @@ def add_branch_protection_main(repo, answers, headers):
 
         target_org = answers.get("target_github_org")
         team_slug = answers.get("target_team_name")
+        team_prefix = answers.get("prefix")
 
-        url = f"https://api.github.com/repos/{target_org}/{repo}/branches/main/protection"
+        url = f"https://api.github.com/repos/{target_org}/{team_prefix}.{repo}/branches/main/protection"
 
         payload = json.dumps({
             "required_status_checks": {
@@ -474,18 +477,21 @@ def transfer_repo(repo, answers, user_found):
             if is_branch_rename_success:
                 is_update_webhook_success = update_webhooks(repo, source_org, answers, headers)
                 if is_update_webhook_success:
-                    is_transfer_success = transfer_repo_to_targetorg(repo, answers, headers)
-                    if is_transfer_success:
-                        logging.info(f"Transfer completed for repo {repo}")
-                        rename_repo(repo, target_org, answers, headers)
+                    is_rename_success = rename_repo(repo, source_org, answers, headers)
+                    if is_rename_success:
+                        is_transfer_success = transfer_repo_to_targetorg(repo, answers, headers)
+                        if is_transfer_success:
+                            logging.info(f"Transfer completed for repo {repo}")
 
-                        # add branch protection rules
-                        add_branch_protection_main(repo, answers, headers)
-                        make_team_admin_writers(repo, answers, headers)
-                        make_repo_internal(repo, answers, headers)
-                        remove_user_as_admin(repo, answers, headers, user_found)
+                            # add branch protection rules
+                            add_branch_protection_main(repo, answers, headers)
+                            make_team_admin_writers(repo, answers, headers)
+                            make_repo_internal(repo, answers, headers)
+                            remove_user_as_admin(repo, answers, headers, user_found)
+                        else:
+                            logging.info(f"Transfer failed for repo {repo}")
                     else:
-                        logging.info(f"Transfer failed for repo {repo}")
+                        logging.info(f"Renaming failed for repo {repo}")
                 else:
                     logging.info(f"updating webhooks failed for repo {repo}")
             else:
